from fastapi import FastAPI, APIRouter, Request, Response

router = APIRouter()

@router.get("/check")
async def login():
    return {"name": "Tester"}

### Plugable API ########################################################################
from danbi import plugable
class Test(plugable.IPlugin):
    def plug(self, **kwargs) -> bool:
        app: FastAPI = kwargs["app"]
        app.include_router(router, prefix="/api_v1/test", tags=["TEST"])
 
        return True
    
    def unplug(self, **kwargs) -> bool:
        return True



from danbi.database import setPsql

setPsql(
    user="realquant",
    password="realquant",
    host="rsnet2",
    port=5432,
    database="realquant",
    pool_min=1,
    pool_max=20,
    base_package="grafana_fastapi",
    mappers=[
        "price.yaml",
    ],
    namespace="realquant",
    tag=1.0
)